@@ -316,7 +316,7 @@ class NonBlockingTCP(NonBlockingTransport, IdleObject):
     estabilish TLS connection.
     """
     def __init__(self, raise_event, on_disconnect, idlequeue, estabilish_tls,
-    certs, tls_version, cipher_list, proxy_dict=None):
+    certs, tls_version, cipher_list, alpn, proxy_dict=None):
         """
         :param proxy_dict: dictionary with proxy data as loaded from config file
         """
@@ -341,6 +341,8 @@ class NonBlockingTCP(NonBlockingTransport, IdleObject):
         self.ssl_certificate = None
         self.ssl_errnum = 0
 
+        self.alpn = alpn
+
     # FIXME: transport should not be aware xmpp
     def start_disconnect(self):
         NonBlockingTransport.start_disconnect(self)
@@ -432,7 +434,7 @@ class NonBlockingTCP(NonBlockingTransport, IdleObject):
         """
         cacerts, mycerts = self.certs
         result = tls_nb.NonBlockingTLS.get_instance(cacerts, mycerts,
-            self.tls_version, self.cipher_list).PlugIn(self)
+            self.tls_version, self.cipher_list, self.alpn).PlugIn(self)
         if result:
             on_succ()
         else:
@@ -609,13 +611,13 @@ class NonBlockingTCP(NonBlockingTransport, IdleObject):
         try:
             # get as many bites, as possible, but not more than RECV_BUFSIZE
             received = self._recv(RECV_BUFSIZE)
-        except socket.error as e:
-            log.info("_do_receive: got %s:" % received, exc_info=True)
         except tls_nb.SSLWrapper.Error as e:
             log.info("_do_receive, caught SSL error, got %s:" % received,
                     exc_info=True)
             errnum, errstr = e.errno,\
                 decode_py2(e.strerror, locale.getpreferredencoding())
+        except socket.error as e:
+            log.info("_do_receive: got %s:" % received, exc_info=True)
 
         if received == '':
             errstr = 'zero bytes on recv'
